@@ -5,8 +5,8 @@ import nbconvert  # type: ignore
 from fastapi import APIRouter, Depends
 from fastapi.responses import FileResponse
 from fps.hooks import register_router  # type: ignore
-from fps_auth.backends import current_user  # type: ignore
-from fps_auth.models import UserRead  # type: ignore
+
+from jupyverse import User, current_user
 
 router = APIRouter()
 
@@ -24,7 +24,7 @@ async def get_nbconvert_document(
     format: str,
     path: str,
     download: bool,
-    user: UserRead = Depends(current_user),
+    user: User = Depends(current_user(permissions={"nbconvert": ["read"]})),
 ):
     exporter = nbconvert.exporters.get_exporter(format)
     if download:
